@@ -4,7 +4,7 @@ from . import discover_devices, discover_media, player
 
 bp = Blueprint('endpoints', __name__)
 
-@bp.route("/discover")
+@bp.route("/discover_chromecasts")
 def home():
     services = discover_devices.discover_chromecasts()
     chromecasts = []
@@ -30,8 +30,9 @@ def cast(input, ip, port):
     player.play_to_chromecast2(input, ip, port)
     return f"Success to {ip} and {port}??"
 
-@bp.route("/test")
+@bp.route("/discover_media")
 def test():
+    discover_media.discover_inputs()
     return {"inputs": discover_media.discover_inputs()}
 
 @bp.route("/play")
